.. image:: https://github.com/amanchokshi/EMBERS/raw/master/docs/_static/imgs/embers.gif
    :width: 100%
    :align: center
    :target: https://embers.readthedocs.io/
    :alt: EMBERS logo

*Experimental Measurement of BEam Responses with Satellites*
============================================================
|PyPI| |ReadTheDocs| |License| |Python|

*EMBERS* is a pure-Python astronomy software package designed to enable polarised measurements of radio telescope antenna beam-patterns using satellites.

*EMBERS* is designed to install cleanly with a single invocation of the standard Python package tool::

    $ pip install embers

Here are the essential project links:

* `Home page and documentation <https://embers.readthedocs.io/en/latest/>`_

* `Installing Embers <https://embers.readthedocs.io/en/latest/installation.html>`_

* `Embers by Example <https://embers.readthedocs.io/en/latest/embersbyexample.html>`_

* `Embers package <https://pypi.org/project/embers/>`_ on the Python Package Index

* `Issue tracker <https://github.com/amanchokshi/EMBERS/issues>`_ on GitHub

.. |ReadTheDocs| image:: https://img.shields.io/readthedocs/embers/latest?color=green&logo=Read%20The%20Docs&logoColor=white
    :target: https://embers.readthedocs.io
    :alt: Documentation Status

.. |PyPI| image:: https://img.shields.io/pypi/v/EMBERS.svg?color=green&logo=python&logoColor=white&label=PyPI
    :target: https://pypi.org/project/embers/
    :alt: PyPI - Latest Release

.. |License| image:: https://img.shields.io/github/license/amanchokshi/EMBERS?color=green&logo=data:image/png;base64, 
    :target: https://github.com/amanchokshi/EMBERS/blob/master/LICENSE
    :alt: MIT License

.. |Python| image:: https://img.shields.io/badge/Python-3.6%2B-3282b8?logo=python&logoColor=white
    :target: https://pypi.org/project/embers/
